==> pdfjs-dist-3.5.141.jar: META-INF/resources/webjars/pdfjs-dist/3.5.141/types/src/pdf.d.ts <==
export type OnProgressParameters = import("./display/api").OnProgressParameters;
export type PDFDocumentLoadingTask = import("./display/api").PDFDocumentLoadingTask;
export type PDFDocumentProxy = import("./display/api").PDFDocumentProxy;
export type PDFPageProxy = import("./display/api").PDFPageProxy;
export type RenderTask = import("./display/api").RenderTask;
export type PageViewport = import("./display/display_utils").PageViewport;
export type TextLayerRenderTask = import("./display/text_layer").TextLayerRenderTask;
import { AbortException } from "./shared/util.js";
import { AnnotationEditorLayer } from "./display/editor/annotation_editor_layer.js";
import { AnnotationEditorParamsType } from "./shared/util.js";
import { AnnotationEditorType } from "./shared/util.js";
import { AnnotationEditorUIManager } from "./display/editor/tools.js";
import { AnnotationLayer } from "./display/annotation_layer.js";
import { AnnotationMode } from "./shared/util.js";
import { build } from "./display/api.js";
import { CMapCompressionType } from "./shared/util.js";
import { createPromiseCapability } from "./shared/util.js";
import { createValidAbsoluteUrl } from "./shared/util.js";
import { FeatureTest } from "./shared/util.js";
import { getDocument } from "./display/api.js";
import { getFilenameFromUrl } from "./display/display_utils.js";
import { getPdfFilenameFromUrl } from "./display/display_utils.js";
import { getXfaPageViewport } from "./display/display_utils.js";
import { GlobalWorkerOptions } from "./display/worker_options.js";
import { InvalidPDFException } from "./shared/util.js";
import { isDataScheme } from "./display/display_utils.js";
import { isPdfFile } from "./display/display_utils.js";
import { loadScript } from "./display/display_utils.js";
import { MissingPDFException } from "./shared/util.js";
import { OPS } from "./shared/util.js";
import { PasswordResponses } from "./shared/util.js";
import { PDFDataRangeTransport } from "./display/api.js";
import { PDFDateString } from "./display/display_utils.js";
import { PDFWorker } from "./display/api.js";
import { PermissionFlag } from "./shared/util.js";
import { PixelsPerInch } from "./display/display_utils.js";
import { RenderingCancelledException } from "./display/display_utils.js";
import { renderTextLayer } from "./display/text_layer.js";
import { setLayerDimensions } from "./display/display_utils.js";
import { shadow } from "./shared/util.js";
import { SVGGraphics } from "./display/svg.js";
import { UnexpectedResponseException } from "./shared/util.js";
import { updateTextLayer } from "./display/text_layer.js";
import { Util } from "./shared/util.js";
import { VerbosityLevel } from "./shared/util.js";
import { version } from "./display/api.js";
import { XfaLayer } from "./display/xfa_layer.js";
export { AbortException, AnnotationEditorLayer, AnnotationEditorParamsType, AnnotationEditorType, AnnotationEditorUIManager, AnnotationLayer, AnnotationMode, build, CMapCompressionType, createPromiseCapability, createValidAbsoluteUrl, FeatureTest, getDocument, getFilenameFromUrl, getPdfFilenameFromUrl, getXfaPageViewport, GlobalWorkerOptions, InvalidPDFException, isDataScheme, isPdfFile, loadScript, MissingPDFException, OPS, PasswordResponses, PDFDataRangeTransport, PDFDateString, PDFWorker, PermissionFlag, PixelsPerInch, RenderingCancelledException, renderTextLayer, setLayerDimensions, shadow, SVGGraphics, UnexpectedResponseException, updateTextLayer, Util, VerbosityLevel, version, XfaLayer };

==> pdfjs-dist-3.6.172.jar: META-INF/resources/webjars/pdfjs-dist/3.6.172/types/src/pdf.d.ts <==
export type OnProgressParameters = import("./display/api").OnProgressParameters;
export type PDFDocumentLoadingTask = import("./display/api").PDFDocumentLoadingTask;
export type PDFDocumentProxy = import("./display/api").PDFDocumentProxy;
export type PDFPageProxy = import("./display/api").PDFPageProxy;
export type RenderTask = import("./display/api").RenderTask;
export type PageViewport = import("./display/display_utils").PageViewport;
export type TextLayerRenderTask = import("./display/text_layer").TextLayerRenderTask;
import { AbortException } from "./shared/util.js";
import { AnnotationEditorLayer } from "./display/editor/annotation_editor_layer.js";
import { AnnotationEditorParamsType } from "./shared/util.js";
import { AnnotationEditorType } from "./shared/util.js";
import { AnnotationEditorUIManager } from "./display/editor/tools.js";
import { AnnotationLayer } from "./display/annotation_layer.js";
import { AnnotationMode } from "./shared/util.js";
import { build } from "./display/api.js";
import { CMapCompressionType } from "./shared/util.js";
import { createValidAbsoluteUrl } from "./shared/util.js";
import { FeatureTest } from "./shared/util.js";
import { getDocument } from "./display/api.js";
import { getFilenameFromUrl } from "./display/display_utils.js";
import { getPdfFilenameFromUrl } from "./display/display_utils.js";
import { getXfaPageViewport } from "./display/display_utils.js";
import { GlobalWorkerOptions } from "./display/worker_options.js";
import { InvalidPDFException } from "./shared/util.js";
import { isDataScheme } from "./display/display_utils.js";
import { isPdfFile } from "./display/display_utils.js";
import { loadScript } from "./display/display_utils.js";
import { MissingPDFException } from "./shared/util.js";
import { normalizeUnicode } from "./shared/util.js";
import { OPS } from "./shared/util.js";
import { PasswordResponses } from "./shared/util.js";
import { PDFDataRangeTransport } from "./display/api.js";
import { PDFDateString } from "./display/display_utils.js";
import { PDFWorker } from "./display/api.js";
import { PermissionFlag } from "./shared/util.js";
import { PixelsPerInch } from "./display/display_utils.js";
import { PromiseCapability } from "./shared/util.js";
import { RenderingCancelledException } from "./display/display_utils.js";
import { renderTextLayer } from "./display/text_layer.js";
import { setLayerDimensions } from "./display/display_utils.js";
import { shadow } from "./shared/util.js";
import { SVGGraphics } from "./display/svg.js";
import { UnexpectedResponseException } from "./shared/util.js";
import { updateTextLayer } from "./display/text_layer.js";
import { Util } from "./shared/util.js";
import { VerbosityLevel } from "./shared/util.js";
import { version } from "./display/api.js";
import { XfaLayer } from "./display/xfa_layer.js";
export { AbortException, AnnotationEditorLayer, AnnotationEditorParamsType, AnnotationEditorType, AnnotationEditorUIManager, AnnotationLayer, AnnotationMode, build, CMapCompressionType, createValidAbsoluteUrl, FeatureTest, getDocument, getFilenameFromUrl, getPdfFilenameFromUrl, getXfaPageViewport, GlobalWorkerOptions, InvalidPDFException, isDataScheme, isPdfFile, loadScript, MissingPDFException, normalizeUnicode, OPS, PasswordResponses, PDFDataRangeTransport, PDFDateString, PDFWorker, PermissionFlag, PixelsPerInch, PromiseCapability, RenderingCancelledException, renderTextLayer, setLayerDimensions, shadow, SVGGraphics, UnexpectedResponseException, updateTextLayer, Util, VerbosityLevel, version, XfaLayer };
